package android.lib.database;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Marks a field as part of a composite index.
 * <p>The annotated field must also be annotated with {@link Column @Column}.</p>
 * <p>The annotated field can also be marked as a single-column index by using {@link Index @Index}.
 * <p>To mark a field as part of an <i>unique</i> composite index, use {@link UniqueCompositeIndex @UniqueCompositeIndex}.</p>
 * @see Column
 * @see Index
 * @see UniqueCompositeIndex
 */
@Target({ ElementType.FIELD })
@Retention(RetentionPolicy.RUNTIME)
public @interface CompositeIndex {
    /**
     * The names of the composite indexes.
     * <p>When there is more than one field annotated, all of them will be included in the composite index under this name.</p>
     * <p>{@link value} cannot be <code>null</code>.</p>
     */
    String[] value() default {};

    /**
     * The order of the annotated field in the composite index.
     * <p>The value can be arbitrary. The final order is determined by comparing this value.</p>
     */
    int order();
}
