package android.lib.database;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Marks a field as indexed.
 * <p>The annotated field must also be annotated with {@link Column @Column}.</p>
 * <p>To mark a field as part of a composite index, use {@link CompositeIndex @CompositeIndex}.
 * @see Column
 * @see CompositeIndex
 */
@Target({ ElementType.FIELD })
@Retention(RetentionPolicy.RUNTIME)
public @interface Index {
    /**
     * The name of the index to be created.
     * </p>If not specified, the name in exact case of the field will be used.</p>
     */
    String value() default "";

    /**
     * <code>true</code> if the index is unique; otherwise, <code>false</code>.
     */
    boolean unique() default false;
}
