package android.lib.database;

/**
 * Converts a value of a type to another type.
 * <p>SQLite-compatible types include <code>boolean</code>, <code>byte</code>, <code>byte[]</code>,
 * <code>double</code>, <code>float</code>, <code>int</code>, <code>long</code>, <code>short</code>
 * and <code>String</code>.
 * @param <F> the type to convert from SQLite-compatible values.
 * @param <T> the type to convert to.
 */
public interface TypeConverter<F, T> {
    /**
     * Converts <code>value</code> of SQLite-compatible type <code>F</code> to type <code>T</code>.
     * @param value the value to convert.
     */
    T fromDatabase(F value);

    /**
     * Converts <code>value</code> of type <code>T</code> to type <code>F</code>
     * that is SQLite-compatible.
     * @param value the value to convert.
     */
    F toDatabase(T value);
}
