package android.lib.database.query;

import android.lib.database.Table;
import android.text.TextUtils;

public abstract class QueryBuilder {
    protected QueryBuilder() {
    }

    /**
     * Builds a SQL statement and abstracts it in a {@link Query} object ready for execution.
     * @return a {@link Query} object ready for execution.
     */
    public abstract Query build();

    /**
     * Returns the name of the table by either its annotated table name or {@link Class#getSimpleName()}.
     * @return the name of the table.
     */
    protected static String getTableName(final Class<?> table) {
        final Table annotation = table.getAnnotation(Table.class);

        return annotation == null ? null : TextUtils.isEmpty(annotation.value()) ? table.getSimpleName() : annotation.value();
    }
}
